#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 2009
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

APARID=IZ52937
FIXFILENAME=wvsapp.ear
FIXFILENAME2=libibmgram.so
#DESTDIR relative to $WVS_ROOT
DESTDIR=/ear
DESTDIR2=/ViaVoice/bin
APPNAME=wvsapp

if [ ! "$2" ] 
then
  if [  -f ./$APARID.sh ]
 then
 echo "Ifix_$APARID: WVS Ifix $APARID Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_$APARID.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$APARID.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_$APARID: WVS Ifix $APARID Installer command syntax: "
 echo " to install ifix  syntax: ifix_$APARID -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$APARID.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /usr/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   . /usr/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_$APARID: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_$APARID: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak ] ; then
    echo "Ifix_$APARID: Ifix $APARID is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
  if [ ! -d $WVS_ROOT/fixes/5.1.3.3 ] ; then
    echo "Ifix_$APARID: Pre-requisite Fixpack 5.1.3.3 is not applied, please install Fixpack 5.1.3.3 before trying to install ifix $APARID"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_$APARID: Checking for ifix files ..."
  if [ -f $thisDir/$FIXFILENAME ] ; then
	echo "Ifix_$APARID: Ifix files found.. proceeding to install ifix"
	mkdir -p $WVS_ROOT/ifix/$APARID
	cp -p $thisDir/$APARID.sh $WVS_ROOT/ifix/ifix_$APARID.sh
	cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/$APARID/stopVoiceServer.jacl
	cp -p $WVS_ROOT/$DESTDIR/$FIXFILENAME $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak
  cp -p $WVS_ROOT/$DESTDIR2/$FIXFILENAME2 $WVS_ROOT/ifix/$APARID/$FIXFILENAME2.bak
	cp -p $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ifix/$APARID/installEar.jacl.bak

	# Backup SIV config files ----------------------------------------------------
	echo "Ifix_$APARID: Backing up SIV config files..."
	mkdir -p $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	echo "Ifix_$APARID: SIV config backup complete."
	# ----------------------------------------------------------------------------

	echo "Ifix_$APARID: Stopping WebSphere Application Server"
	$WAS_HOME/bin/stopServer.sh server1
	echo $?
	if [ "$?" = "246" -o "$?" = "0" ] ; then
	  echo "Ifix_$APARID: Application Server stopped successful, proceeding to install ifix"
	else
	  echo "Ifix_$APARID: Application Server reported failure during stopping. Ifix installation will not continue"
	  rm -rf $WVS_ROOT/ifix/$APARID
	  exit -1
	fi

	cp -fp $thisDir/$FIXFILENAME $WVS_ROOT/$DESTDIR/. 
  cp -fp $thisDir/$FIXFILENAME2 $WVS_ROOT/$DESTDIR2/.
	cp -fp $thisDir/installEar.jacl $WVS_ROOT/.package/.

	echo "Ifix_$APARID: Starting WebSphere Application Server"


	$WAS_HOME/bin/startServer.sh server1 -quiet
	if [ "$?" = "111" -o "$?" = "0" ] ; then
	  echo "Ifix_$APARID: Application Server started successful, proceeding to install ifix"
	else
	  echo "Ifix_$APARID: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
	  exit -1
	fi

	echo "Ifix_$APARID: Stopping  WebSphere Voice Server"
	$WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
	errorsduringinstall=$?

	echo "Ifix_$APARID: Updating WebSphere Voice Server J2EE Application"
	$WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/$DESTDIR $APPNAME WVS5.1-$thisHostname $thisHostname
	errorsduringinstall=$?

	# Restore SIV config files ---------------------------------------------------
	echo "Ifix_$APARID: Restoring SIV config files..."
	cp -fp $WVS_ROOT/ifix/$APARID/confbck/ibm-web-bnd.xmi  $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.$DESTDIR/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$APARID.log
	cp -fp $WVS_ROOT/ifix/$APARID/confbck/web.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$APARID.log
	cp -fp $WVS_ROOT/ifix/$APARID/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$APARID.log
	cp -fp $WVS_ROOT/ifix/$APARID/confbck/ejb-jar.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$APARID.log

	rm -rf $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
	echo "Ifix_$APARID: SIV config files restored."
	# ----------------------------------------------------------------------------

	if [ $errorsduringinstall = "0" ] ; then
		echo "Ifix_$APARID: Ifix is now applied, please reboot the system"
	else
		echo "Ifix_$APARID: Ifix installation was not successful. Please uninstall. "
	fi
  else
    echo "Ifix_$APARID: Ifix files missing, please be sure this script is in same directory as the binary files" 
  fi
  cp -fp $thisDir/$APARID.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_$APARID: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak ] ; then
      echo "Ifix_$APARID: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_$APARID: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server stopped successful, proceeding to un-install ifix"
      else
         echo "Ifix_$APARID: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/$APARID
         exit -1
      fi
      
	  # Backup SIV config files ----------------------------------------------------
      echo "Ifix_$APARID: Backing up SIV config files..."
      mkdir -p $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      echo "Ifix_$APARID: SIV config backup complete."
      # ----------------------------------------------------------------------------
	  
      cp -fp $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak $WVS_ROOT/$DESTDIR/$FIXFILENAME 
      cp -fp $WVS_ROOT/ifix/$APARID/$FIXFILENAME2.bak  $WVS_ROOT/$DESTDIR2/$FIXFILENAME2
          
      echo "Ifix_$APARID: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_$APARID: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       
      echo "Ifix_$APARID: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/$APARID/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
          
      echo "Ifix_$APARID: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/$DESTDIR $APPNAME WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
	  # Restore config files -------------------------------------------------------
      echo "Ifix_$APARID: Restoring SIV config files..."
      cp -fp $WVS_ROOT/ifix/$APARID/confbck/ibm-web-bnd.xmi  $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$APARID.log
      cp -fp $WVS_ROOT/ifix/$APARID/confbck/web.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$APARID.log
      cp -fp $WVS_ROOT/ifix/$APARID/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$APARID.log
      cp -fp $WVS_ROOT/ifix/$APARID/confbck/ejb-jar.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$APARID.log
	  
      rm -rf $WVS_ROOT/ifix/$APARID/confbck >> $WVS_ROOT/log/$APARID.log
      echo "Ifix_$APARID: SIV config files restored."
      # ----------------------------------------------------------------------------
	  
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_$APARID: Ifix is now uninstalled, please reboot the system"
        echo "Ifix_$APARID:  Please remove the $WVS_ROOT/ifix/$APARID directory before attempting a subsequent install of this ifix."
      else
        echo "Ifix_$APARID: Ifix uninstallation was not successful. Please contact support. "
      fi
    
  else
    echo "Ifix_$APARID: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
